@@ -21,8 +21,8 @@
 #' @name huxtable-package
 NULL
 
-#' @import stats
-#' @import grDevices
+
+#' @importFrom stats na.omit setNames
 NULL
 
 
@@ -482,124 +482,6 @@ merge_props <- function (res, first, second, type = c('cbind', 'rbind'), copy_ce
 }
 
 
-#' @importFrom dplyr filter_
-#' @export
-filter_.huxtable <- function (.data, ..., .dots) {
-  ht <- .data
-  .data <- as.data.frame(.data)
-  .data <- tibble::rownames_to_column(.data, 'filter.huxtable.rownames')
-  result <- NextMethod()
-  ht[.data$filter.huxtable.rownames %in% result$filter.huxtable.rownames, ]
-}
-
-#' Dplyr verbs for huxtable
-#'
-#' Huxtable can be used with dplyr verbs \code{\link[dplyr]{select}}, \code{\link[dplyr]{rename}},
-#' \code{\link[dplyr]{slice}}, \code{\link[dplyr]{arrange}}, \code{\link[dplyr]{mutate}} and
-#' \code{\link[dplyr]{transmute}}. These will return huxtables. Other verbs like \code{\link[dplyr]{summarize}}
-#' will simply return data frames as normal.
-#'
-#' @param .data A huxtable.
-#' @param ...,.dots Arguments passed to \code{\link[dplyr]{mutate}}.
-#'
-#' @details
-#' If \code{mutate} creates new columns, and the argument \code{copy_cell_props} is missing or \code{TRUE}, then cell
-#' and column properties will be copied from existing columns to their left, if there are any. Otherwise, they will be the
-#' standard defaults. Row and table properties, and properties of cells in existing columns, remain unchanged.
-#'
-#' @rdname dplyr-verbs
-#' @aliases mutate
-#' @examples
-#' ht <- hux(a = 1:5, b = 1:5, c = 1:5, d = 1:5)
-#' bold(ht)[c(1, 3), ] <- TRUE
-#' bold(ht)[, 1] <- TRUE
-#' ht2 <- dplyr::select(ht, b:c)
-#' ht2
-#' bold(ht2)
-#' ht3 <- dplyr::mutate(ht, x = a + b)
-#' ht3
-#' bold(ht3)
-#' ht4 <- dplyr::mutate(ht, x = a + b, copy_cell_props = FALSE)
-#' bold(ht4)
-#' @importFrom dplyr mutate_
-#' @export
-mutate_.huxtable <- function (.data, ..., .dots) {
-  ht <- .data
-  .data <- as.data.frame(.data)
-  copy_cell_props <- TRUE
-  if (! is.null(.dots$copy_cell_props)) copy_cell_props <- lazyeval::lazy_eval(.dots$copy_cell_props)
-  .dots <- .dots[setdiff(names(.dots), 'copy_cell_props')]
-  result <- NextMethod()
-  result <- as_hux(result)
-
-  for (a in c(huxtable_row_attrs, huxtable_table_attrs)) attr(result, a) <- attr(ht, a)
-
-  # unlike in extract-methods we can't assume that new columns are on the right: transmute can reorder them
-  # columns may even be reordered by e.g. a=NULL,...,a=new_value
-  # so: all columns with an old name get the old attributes. New columns get copied attributes maybe.
-  match_cols <- match(colnames(result), colnames(ht))
-  if (copy_cell_props) match_cols <- Reduce(function (x, y) if (is.na(y)) x else y, match_cols, accumulate = TRUE)
-  result_cols <- ! is.na(match_cols)
-  match_cols  <- na.omit(match_cols)
-
-  for (a in huxtable_cell_attrs) attr(result, a)[, result_cols] <- attr(ht, a)[, match_cols]
-  for (a in huxtable_col_attrs)  attr(result, a)[result_cols]  <- attr(ht, a)[match_cols]
-
-  result <- set_attr_dimnames(result)
-
-  result
-}
-
-
-#' @importFrom dplyr transmute_
-#' @export
-transmute_.huxtable <- mutate_.huxtable
-
-#' @importFrom dplyr arrange_
-#' @export
-arrange_.huxtable <- function (.data, ..., .dots) {
-  ht <- .data
-  .data <- tibble::rownames_to_column(.data, 'arrange.huxtable.rownames')
-  result <- NextMethod()
-  ht[match(result$arrange.huxtable.rownames, .data$arrange.huxtable.rownames), ]
-}
-
-
-#' @importFrom dplyr slice_
-#' @export
-slice_.huxtable <- function (.data, ..., .dots) {
-  ht <- .data
-  .data <- tibble::rownames_to_column(.data, 'slice.huxtable.rownames')
-  result <- NextMethod()
-  ht[na.omit(match(result$slice.huxtable.rownames, .data$slice.huxtable.rownames)), ]
-}
-
-
-#' @importFrom dplyr select_
-#' @export
-select_.huxtable <- function (.data, ..., .dots) {
-  ht <- .data
-  .data <- as.data.frame(t(colnames(.data)), stringsAsFactors = FALSE)
-  colnames(.data) <- colnames(ht)
-  result <- NextMethod()
-  ht <- ht[, na.omit(match(result[1, ], colnames(ht)))]
-  colnames(ht) <- colnames(result)
-
-  ht
-}
-
-
-#' @importFrom dplyr rename_
-#' @export
-rename_.huxtable <- select_.huxtable
-
-#' @export
-`dimnames<-.huxtable` <- function (x, value) {
-  x <- NextMethod()
-  x <- set_attr_dimnames(x)
-  x
-}
-
 #' Transpose a huxtable
 #'
 #' @param x A huxtable.
@@ -643,14 +525,12 @@ t.huxtable <- function (x) {
 }
 
 
-
-
 #' Add column or row names
 #'
 #' Add a first row of column names, or a first column of row names, to the huxtable.
 #'
 #' Note that \code{add_colnames} will change the mode of all columns to character.
-
+#'
 #' \code{add_colnames} preserves column names. \code{add_rownames} only preserves them if asked to.
 #'
 #' @param ht A huxtable.
@@ -672,6 +552,7 @@ t.huxtable <- function (x) {
 #' @export
 add_colnames <- function (ht, ...) UseMethod('add_colnames')
 
+
 #' @export
 #' @rdname add_colnames
 add_colnames.huxtable <- function (ht, rowname = NULL, ...) {
@@ -682,10 +563,12 @@ add_colnames.huxtable <- function (ht, rowname = NULL, ...) {
   ht
 }
 
+
 #' @export
 #' @rdname add_colnames
 add_rownames <- function (ht, ...) UseMethod('add_rownames')
 
+
 #' @export
 #' @rdname add_colnames
 add_rownames.huxtable <- function (ht, colname = 'rownames', preserve_rownames = TRUE, ...) {
@@ -695,6 +578,15 @@ add_rownames.huxtable <- function (ht, colname = 'rownames', preserve_rownames =
   ht
 }
 
+
+#' @export
+`dimnames<-.huxtable` <- function (x, value) {
+  x <- NextMethod()
+  x <- set_attr_dimnames(x)
+  x
+}
+
+
 set_attr_dimnames <- function(ht) {
   for (a in huxtable_cell_attrs) {
     dimnames(attr(ht, a)) <- dimnames(ht)
